package de.hftstuttgart.unifiedticketing.core;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

public class TicketSystemTest
{
    public TicketSystem instance;

    @BeforeEach
    public void initBeforeEach()
    {
        instance = mock(TicketSystem.class,
            withSettings().useConstructor().defaultAnswer(CALLS_REAL_METHODS));
    }

    @Test
    public void testInit()
    {
        assertAll(
            () -> assertNull(instance.apiKey),
            () -> assertNull(instance.baseUrl),
            () -> assertNull(instance.password),
            () -> assertNull(instance.username)
        );
    }

    @Test
    public void testConfigBoolean()
    {
        assertFalse(instance.getConfigTrue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));

        instance.config(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR, true);
        assertTrue(instance.getConfigTrue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));

        instance.config(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR, false);
        assertFalse(instance.getConfigTrue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));
    }

    @Test
    public void testConfigValue()
    {
        assertNull(instance.getConfigValue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));

        String expected = "some string value";
        instance.config(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR, expected);
        assertFalse(instance.getConfigTrue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));
        assertEquals(expected, instance.getConfigValue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));

        expected = "TRUE";
        instance.config(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR, expected);
        assertTrue(instance.getConfigTrue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));

        instance.config(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR, null);
        assertFalse(instance.getConfigTrue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));
        assertEquals(null, instance.getConfigValue(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR));
    }

    @Test
    public void testGetTicketByIdByInt()
    {
        int input = 5;
        instance.getTicketById(input);
        verify(instance, times(1)).getTicketById(String.valueOf(input));
    }

    @Test
    public void testFluentApi()
    {
        TicketSystem before = instance;
        TicketSystem after = instance
            .config(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR, true)
            .config(TicketSystem.ConfigurationOptions.RETURN_NULL_ON_ERROR, "something");

        assertSame(before, after);
    }
}
